@@ -7,6 +7,8 @@ class Config(object):
   Add all config attributes in the parent class with a default.
   Then override as needed in the environment specific configs
   """
+  LOG_APP_NAME= os.getenv('LOG_APP_NAME')
+  LOG_LEVEL = os.environ.get('LOG_LEVEL', 'INFO')
   GOOGLE_API_KEY = os.getenv('GOOGLE_API_KEY')
   PC_MILER_URL = "https://pcmiler.alk.com/apis/rest/v1.0/Service.svc/locations?postcodeFilter={0}&dataset=Current&authToken={1}"
   PC_MILER_KEY = os.getenv('PC_MILER_KEY')
